<?php

namespace Kaizen_Coders\Url_Shortify\Admin\Controllers;

use Kaizen_Coders\Url_Shortify\Helper;

class ImportController extends BaseController {

	/**
	 * ImportController constructor.
	 *
	 * @since 1.3.4
	 */
	public function __construct() {
		parent::__construct();
	}

	/**
	 * Import Links
	 *
	 * @return bool
	 *
	 * @since 1.4.8
	 */
	public function import_links( $action = '' ) {

		if ( 'pretty_links' === $action ) {
			$do_import = $this->import_pretty_links();
		} elseif ( 'mts_links' === $action ) {
			$do_import = $this->import_mts_short_links();
		} elseif ( 'eps_301_redirects' === $action ) {
			$do_import = $this->import_eps_301_redirect();
		} elseif ( 'simple_301_redirects' === $action ) {
			$do_import = $this->import_from_simple_301_redirect();
		} elseif ( 'thirsty_affiliates' === $action ) {
			$do_import = $this->import_thirsty_affiliate_links();
		} else {
			$do_import = false;
		}

		return $do_import;
	}

	/**
	 * Import Groups
	 *
	 * @param array $groups
	 *
	 * @since 1.4.4
	 */
	public function import_groups( $groups = array() ) {

		if ( Helper::is_forechable( $groups ) ) {

			$existing_groups = US()->db->groups->get_id_name_map();

			$current_user_id = \get_current_user_id();

			$groups_to_import = array();

			$key = 0;
			foreach ( $groups as $group_name => $links ) {

				if ( ! in_array( $group_name, $existing_groups ) ) {
					$groups_to_import[ $key ]['name']          = $group_name;
					$groups_to_import[ $key ]['created_by_id'] = $current_user_id;

					$key ++;
				}
			}

			if ( Helper::is_forechable( $groups_to_import ) ) {
				US()->db->groups->bulk_insert( $groups_to_import );
			}
		}

	}

	/**
	 * Add links to group
	 *
	 * @param array $groups
	 *
	 * @since 1.4.4
	 */
	public function add_links_to_group( $groups = array() ) {

		if ( Helper::is_forechable( $groups ) ) {

			$create_by_id       = \get_current_user_id();
			$groups_name_id_map = US()->db->groups->get_columns_map( 'name', 'id' );

			$links_slug_id_map = US()->db->links->get_columns_map( 'slug', 'id' );

			$data_to_insert = array();

			$key = 0;

			foreach ( $groups as $group => $links ) {

				$group_id = Helper::get_data( $groups_name_id_map, $group, 0 );

				if ( 0 != $group_id ) {

					if ( Helper::is_forechable( $links ) ) {
						foreach ( $links as $slug ) {
							$link_id = Helper::get_data( $links_slug_id_map, $slug, 0 );

							if ( 0 != $link_id ) {
								$data_to_insert[ $key ]['link_id']       = $link_id;
								$data_to_insert[ $key ]['group_id']      = $group_id;
								$data_to_insert[ $key ]['created_by_id'] = $create_by_id;

								$key ++;
							}
						}
					}
				}
			}

			if ( Helper::is_forechable( $data_to_insert ) ) {
				US()->db->links_groups->bulk_insert( $data_to_insert );
			}
		}

	}

	/**
	 * Import links from prettylink WordPress plugin
	 *
	 * @return bool
	 *
	 * @since 1.3.4
	 */
	public function import_pretty_links() {

		global $wpdb;

		$current_user_id = get_current_user_id();
		$links_table     = "{$wpdb->prefix}prli_links";

		$links_table_exists = US()->is_table_exists( $links_table );

		if ( $links_table_exists > 0 ) {

			$query = "SELECT * FROM {$links_table}";

			$links = $wpdb->get_results( $query, ARRAY_A );

			if ( Helper::is_forechable( $links ) ) {

				@set_time_limit( 0 );

				$existing_links = US()->db->links->get_columns_map( 'id', 'slug' );

				$values = $groups = array();

				$key = 0;

				foreach ( $links as $link ) {

					$slug = Helper::get_data( $link, 'slug', '' );

					if ( in_array( $slug, $existing_links ) ) {
						continue;
					}

					$cpt_id = Helper::get_data( $link, 'link_cpt_id', '' );

					$values[ $key ]['slug']              = $slug;
					$values[ $key ]['name']              = ! empty( Helper::get_data( $link, 'name', '' ) ) ? Helper::get_data( $link, 'name', '' ) : Helper::get_data( $link, 'url', '' );
					$values[ $key ]['description']       = Helper::get_data( $link, 'description', '' );
					$values[ $key ]['url']               = Helper::get_data( $link, 'url', '' );
					$values[ $key ]['nofollow']          = Helper::get_data( $link, 'nofollow', '' );
					$values[ $key ]['track_me']          = Helper::get_data( $link, 'track_me', '' );
					$values[ $key ]['sponsored']         = Helper::get_data( $link, 'sponsored', '' );
					$values[ $key ]['params_forwarding'] = Helper::get_data( $link, 'param_forwarding', '' );
					$values[ $key ]['params_structure']  = Helper::get_data( $link, 'params_struct', '' );
					$values[ $key ]['redirect_type']     = Helper::get_data( $link, 'redirect_type', '' );
					$values[ $key ]['status']            = ( 'enabled' === Helper::get_data( $link, 'link_status', 'enabled' ) ) ? 1 : 0;
					$values[ $key ]['type']              = 'direct';
					$values[ $key ]['type_id']           = null;
					$values[ $key ]['password']          = null;
					$values[ $key ]['expires_at']        = null;
					$values[ $key ]['cpt_id']            = $cpt_id;
					$values[ $key ]['cpt_type']          = Helper::get_data( $link, 'link_cpt_type', '' );
					$values[ $key ]['rules']             = null;
					$values[ $key ]['created_at']        = Helper::get_data( $link, 'created_at', '' );
					$values[ $key ]['created_by_id']     = $current_user_id;
					$values[ $key ]['updated_at']        = Helper::get_data( $link, 'updated_at', '' );
					$values[ $key ]['updated_by_id']     = $current_user_id;

					// Collect all categories
					if ( ! empty( $cpt_id ) ) {
						$terms = get_the_terms( $cpt_id, 'pretty-link-category' );

						if ( Helper::is_forechable( $terms ) ) {
							foreach ( $terms as $term ) {
								$groups[ $term->name ][] = $slug;
							}
						}
					}

					$key ++;
				}

				// Import Links
				if ( Helper::is_forechable( $values ) ) {
					US()->db->links->bulk_insert( $values );
				}

				if ( Helper::is_forechable( $groups ) ) {

					// Import Groups
					$this->import_groups( $groups );

					// Map Link <-> Group
					$this->add_links_to_group( $groups );
				}

			}
		}

		return true;
	}

	/**
	 * Import links from My theme shop short links WordPress plugin
	 *
	 * @return bool
	 *
	 * @since 1.3.4
	 */
	public function import_mts_short_links() {

		global $wpdb;

		$links_table = "{$wpdb->prefix}short_links";

		$links_table_exists = US()->is_table_exists( $links_table );

		if ( $links_table_exists > 0 ) {

			$query = "SELECT * FROM {$links_table}";

			$links = $wpdb->get_results( $query, ARRAY_A );

			if ( Helper::is_forechable( $links ) ) {

				@set_time_limit( 0 );

				$existing_links = US()->db->links->get_columns_map( 'id', 'slug' );

				$values = $groups = array();

				$key = 0;

				foreach ( $links as $link ) {

					$slug = Helper::get_data( $link, 'link_name', '' );

					if ( in_array( $slug, $existing_links ) ) {
						continue;
					}

					$link_id = Helper::get_data( $link, 'link_id', 0 );

					$values[ $key ]['slug']              = $slug;
					$values[ $key ]['name']              = ! empty( Helper::get_data( $link, 'link_title', '' ) ) ? Helper::get_data( $link, 'link_title', '' ) : Helper::get_data( $link, 'link_url', '' );
					$values[ $key ]['description']       = Helper::get_data( $link, 'link_description', '' );
					$values[ $key ]['url']               = Helper::get_data( $link, 'link_url', '' );
					$values[ $key ]['nofollow']          = ( "nofollow" === Helper::get_data( $link, 'link_attr_rel', 'nofollow' ) ) ? 1 : 0;
					$values[ $key ]['track_me']          = 1;
					$values[ $key ]['sponsored']         = 0;
					$values[ $key ]['params_forwarding'] = Helper::get_data( $link, 'link_forward_parameters', 0 );
					$values[ $key ]['params_structure']  = null;
					$values[ $key ]['redirect_type']     = Helper::get_data( $link, 'link_redirection_method', 307 );
					$values[ $key ]['status']            = ( 'publish' === Helper::get_data( $link, 'link_status', 'publish' ) ) ? 1 : 0;
					$values[ $key ]['type']              = 'direct';
					$values[ $key ]['type_id']           = null;
					$values[ $key ]['password']          = null;
					$values[ $key ]['expires_at']        = null;
					$values[ $key ]['cpt_id']            = null;
					$values[ $key ]['cpt_type']          = null;
					$values[ $key ]['rules']             = null;
					$values[ $key ]['created_at']        = Helper::get_data( $link, 'link_created', '' );
					$values[ $key ]['created_by_id']     = Helper::get_data( $link, 'link_owner', '' );
					$values[ $key ]['updated_at']        = Helper::get_data( $link, 'link_updated', '' );
					$values[ $key ]['updated_by_id']     = Helper::get_data( $link, 'link_owner', '' );

					// Collect all categories
					if ( ! empty( $link_id ) ) {
						$categories = wp_get_object_terms( $link_id, 'short_link_category', array( 'fields' => 'ids' ) );
						$categories = array_unique( $categories );

						if ( Helper::is_forechable( $categories ) ) {

							foreach ( $categories as $category ) {
								$term = get_term( $category, 'short_link_category' );

								$groups[ $term->name ][] = $slug;
							}
						}
					}

					$key ++;
				}

				// Import Links
				if ( Helper::is_forechable( $values ) ) {
					US()->db->links->bulk_insert( $values );
				}

				if ( Helper::is_forechable( $groups ) ) {

					// Import Groups
					$this->import_groups( $groups );

					// Map Link <-> Group
					$this->add_links_to_group( $groups );
				}
			}
		}

		return true;
	}

	/**
	 * Import links from 301 Redirect - Easy Redirect Manager WordPress plugin
	 *
	 * https://wordpress.org/plugins/eps-301-redirects/
	 *
	 * @return bool
	 *
	 * @since 1.3.4
	 */
	public function import_eps_301_redirect() {

		global $wpdb;

		$links_table = "{$wpdb->prefix}redirects";

		$links_table_exists = US()->is_table_exists( $links_table );

		if ( $links_table_exists > 0 ) {

			$query = "SELECT * FROM {$links_table}";

			$links = $wpdb->get_results( $query, ARRAY_A );

			if ( Helper::is_forechable( $links ) ) {

				@set_time_limit( 0 );

				$existing_links = US()->db->links->get_columns_map( 'id', 'slug' );

				$values = $groups = array();

				$key = 0;

				$settings = US()->get_settings();

				$default_nofollow          = Helper::get_data( $settings, 'links_default_link_options_enable_nofollow', 1 );
				$default_track_me          = Helper::get_data( $settings, 'links_default_link_options_enable_tracking', 1 );
				$default_sponsored         = Helper::get_data( $settings, 'links_default_link_options_enable_sponsored', 1 );
				$default_params_forwarding = Helper::get_data( $settings, 'links_default_link_options_enable_paramter_forwarding', 1 );
				$default_redirect_type     = Helper::get_data( $settings, 'links_default_link_options_redirection_type', 301 );

				$default_created_at    = date( 'Y-m-d H:i:s' );
				$default_created_by_id = \get_current_user_id();

				foreach ( $links as $link ) {

					$slug = Helper::get_data( $link, 'url_from', '' );

					if ( '*' === $slug || in_array( $slug, $existing_links ) ) {
						continue;
					}

					$status = Helper::get_data( $link, 'status', 'off' );

					// We know only these statuses of 301 Redirects
					if ( ! in_array( $status, array( '301', '302', '307' ) ) ) {
						continue;
					}

					$values[ $key ]['slug']              = $slug;
					$values[ $key ]['name']              = 'Easy 301 Redirect - ' . $slug;
					$values[ $key ]['description']       = 'Imported From Easy 301 Redirect';
					$values[ $key ]['url']               = Helper::get_data( $link, 'url_to', '' );
					$values[ $key ]['nofollow']          = $default_nofollow;
					$values[ $key ]['track_me']          = $default_track_me;
					$values[ $key ]['sponsored']         = $default_sponsored;
					$values[ $key ]['params_forwarding'] = $default_params_forwarding;
					$values[ $key ]['redirect_type']     = Helper::get_data( $link, 'status', $default_redirect_type );
					$values[ $key ]['status']            = 1;
					$values[ $key ]['type']              = 'direct';
					$values[ $key ]['created_at']        = $default_created_at;
					$values[ $key ]['created_by_id']     = $default_created_by_id;

					$groups['Easy 301 Redirect'][] = $slug;

					$key ++;
				}

				// Import Links
				if ( Helper::is_forechable( $values ) ) {
					US()->db->links->bulk_insert( $values );
				}

				if ( Helper::is_forechable( $groups ) ) {

					// Import Groups
					$this->import_groups( $groups );

					// Map Link <-> Group
					$this->add_links_to_group( $groups );
				}

			}
		}

		return true;
	}

	/**
	 * Import links from Simple 301 Redirect WordPress plugin
	 *
	 * https://wordpress.org/plugins/simple-301-redirects/
	 *
	 * @return bool
	 *
	 * @since 1.3.4
	 */
	public function import_from_simple_301_redirect() {

		global $wpdb;

		$plugin_installed = Helper::is_simple_301_redirect_plugin_installed();

		if ( $plugin_installed ) {

			$links = maybe_unserialize( get_option( '301_redirects' ) );

			if ( Helper::is_forechable( $links ) ) {

				@set_time_limit( 0 );

				$existing_links = US()->db->links->get_columns_map( 'id', 'slug' );

				$values = $groups = array();

				$key = 0;

				$settings = US()->get_settings();

				$default_nofollow          = Helper::get_data( $settings, 'links_default_link_options_enable_nofollow', 1 );
				$default_track_me          = Helper::get_data( $settings, 'links_default_link_options_enable_tracking', 1 );
				$default_sponsored         = Helper::get_data( $settings, 'links_default_link_options_enable_sponsored', 1 );
				$default_params_forwarding = Helper::get_data( $settings, 'links_default_link_options_enable_paramter_forwarding', 1 );

				$default_created_at    = date( 'Y-m-d H:i:s' );
				$default_created_by_id = \get_current_user_id();

				foreach ( $links as $slug => $target_url ) {

					$slug = ltrim( $slug, '/' );

					if ( '*' === $slug || in_array( $slug, $existing_links ) ) {
						continue;
					}

					$values[ $key ]['slug']              = $slug;
					$values[ $key ]['name']              = 'Simple 301 Redirect - ' . $slug;
					$values[ $key ]['description']       = 'Imported From Simple 301 Redirect';
					$values[ $key ]['url']               = $target_url;
					$values[ $key ]['nofollow']          = $default_nofollow;
					$values[ $key ]['track_me']          = $default_track_me;
					$values[ $key ]['sponsored']         = $default_sponsored;
					$values[ $key ]['params_forwarding'] = $default_params_forwarding;
					$values[ $key ]['redirect_type']     = 301;
					$values[ $key ]['status']            = 1;
					$values[ $key ]['type']              = 'direct';
					$values[ $key ]['created_at']        = $default_created_at;
					$values[ $key ]['created_by_id']     = $default_created_by_id;

					$groups['Simple 301 Redirect'][] = $slug;

					$key ++;
				}

				// Import Links
				if ( Helper::is_forechable( $values ) ) {
					US()->db->links->bulk_insert( $values );
				}


				if ( Helper::is_forechable( $groups ) ) {

					// Import Groups
					$this->import_groups( $groups );

					// Map Link <-> Group
					$this->add_links_to_group( $groups );
				}

			}
		}

		return true;
	}

	/**
	 * Import links from Thirsty Affiliate WordPress plugin
	 *
	 * @return bool
	 *
	 * @since 1.4.8
	 */
	public function import_thirsty_affiliate_links() {
		return false;
	}

}
